@@ -332,141 +332,95 @@ class ApiManager:
 
             already_created_by_name = {}
 
+            msg = []
+
             for source_to_import in data:
 
                 if needed_keys.issubset(source_to_import.keys()):
 
-                    which_type = None
-
-                    if self.evergreen_enabled:
+                    if source_to_import["type"] in non_evergreen_conversion_type:
 
                         which_type = non_evergreen_conversion_type[source_to_import["type"]]
 
-                        if which_type in ["external", "api_dataset"]:
-
-                            file_dir, path = mkstemp(suffix=".csv")
-
-                            open(path, "wb").write(
-                                json_to_csv(
-                                    source_to_import["file_content"],
-                                    io_format=False
-                                ).encode()
-                            )
-
-                            new_source = self.sources.static_file_upload(
-                                name=source_to_import["name"],
-                                content=path,
-                                org_id=org_id
-                            )
-
-                            source_to_import["new_source_id"] = new_source["id"]
-
-                            already_created_by_name[source_to_import["name"]] = new_source["id"]
-
-                            os.close(file_dir)
-                            try:
-                                os.remove(path)
-                            except OSError:
-                                pass
-
-                        if which_type in ["piconfig", "web"]:
-
-                            file_dir, path = mkstemp(suffix=".csv")
-
-                            server_name = remove_special(
-                                out_file=path,
-                                data_array=source_to_import["file_content"]
-                            )
-
-                            if server_name is None:
-                                server_name = "PITAGCONFIGFILESERVER"
-
-                            new_source = self.sources.pi_config_upload(
-                                name=source_to_import["name"],
-                                server_name=server_name,
-                                file_path=path,
-                                org_id=org_id
-                            )
-
-                            source_to_import["new_source_id"] = new_source["id"]
-
-                            already_created_by_name[source_to_import["name"]] = new_source["id"]
-
-                            os.close(file_dir)
-                            try:
-                                os.remove(path)
-                            except OSError:
-                                pass
-
                     else:
-                        which_type = non_evergreen_conversion_type[source_to_import["type"]]
+                        which_type = "api_dataset"
 
-                        if source_to_import["name"] in already_created_by_name:
+                    if which_type in ["api_dataset"]:
+                        new_source = self.sources.create_api_data_set_with_content(
+                            name=source_to_import["name"],
+                            org_id=org_id,
+                            content=json_to_csv(
+                                source_to_import["file_content"],
+                                io_format=False
+                            )
+                        )
 
-                            source_to_import["new_source_id"] = already_created_by_name[
-                                source_to_import["name"]
-                            ]
+                        source_to_import["new_source_id"] = new_source["data_set_id"]
 
-                        else:
-                            if which_type in ["external", "web"]:
+                        msg.append("DataSource '{}' imported successfully".format(source_to_import["name"]))
 
-                                file_dir, path = mkstemp(suffix=".csv")
+                    if which_type in ["external"]:
 
-                                open(path, "wb").write(
-                                    json_to_csv(
-                                        source_to_import["file_content"],
-                                        io_format=False
-                                    ).encode()
-                                )
+                        file_dir, path = mkstemp(suffix=".csv")
 
-                                new_source = self.sources.static_file_upload(
-                                    name=source_to_import["name"],
-                                    content=path,
-                                    org_id=org_id
-                                )
+                        open(path, "wb").write(
+                            json_to_csv(
+                                source_to_import["file_content"],
+                                io_format=False
+                            ).encode()
+                        )
 
-                                source_to_import["new_source_id"] = new_source["id"]
+                        new_source = self.sources.static_file_upload(
+                            name=source_to_import["name"],
+                            content=path,
+                            org_id=org_id
+                        )
 
-                                already_created_by_name[source_to_import["name"]] = new_source["id"]
+                        source_to_import["new_source_id"] = new_source["id"]
 
-                                os.close(file_dir)
+                        already_created_by_name[source_to_import["name"]] = new_source["id"]
 
-                                try:
-                                    os.remove(path)
-                                except OSError:
-                                    pass
-                            if which_type == "piconfig":
+                        msg.append("DataSource '{}' imported successfully".format(source_to_import["name"]))
 
-                                file_dir, path = mkstemp(suffix=".csv")
+                        os.close(file_dir)
+                        try:
+                            os.remove(path)
+                        except OSError:
+                            pass
 
-                                server_name = remove_special(
-                                    out_file=path,
-                                    data_array=source_to_import["file_content"]
-                                )
+                    if which_type in ["piconfig", "web"]:
 
-                                if server_name is None:
-                                    server_name = "PITAGCONFIGFILESERVER"
+                        file_dir, path = mkstemp(suffix=".csv")
 
-                                new_source = self.sources.pi_config_upload(
-                                    name=source_to_import["name"],
-                                    server_name=server_name,
-                                    file_path=path,
-                                    org_id=org_id
-                                )
+                        server_name = remove_special(
+                            out_file=path,
+                            data_array=source_to_import["file_content"]
+                        )
 
-                                source_to_import["new_source_id"] = new_source["id"]
-                                already_created_by_name[source_to_import["name"]] = new_source["id"]
+                        if server_name is None:
+                            server_name = "PITAGCONFIGFILESERVER"
 
-                                os.close(file_dir)
+                        new_source = self.sources.pi_config_upload(
+                            name=source_to_import["name"],
+                            server_name=server_name,
+                            file_path=path,
+                            org_id=org_id
+                        )
 
-                                try:
-                                    os.remove(path)
-                                except OSError:
-                                    pass
+                        source_to_import["new_source_id"] = new_source["id"]
 
+                        already_created_by_name[source_to_import["name"]] = new_source["id"]
 
+                        msg.append("DataSource '{}' imported successfully".format(source_to_import["name"]))
+
+                        os.close(file_dir)
+                        try:
+                            os.remove(path)
+                        except OSError:
+                            pass
 
                 else:
+
                     raise Exception("Missing export data {} ".format(
                         needed_keys.difference(source_to_import.keys()))
                     )
@@ -496,7 +450,7 @@ class ApiManager:
 
                 return json.dumps(pipeline_info)
 
-            return "Data sets imported successfully"
+            return str(msg)
 
         except Exception as error:
             raise error
@@ -527,7 +481,7 @@ class ApiManager:
             current_name_to_id = {}
 
             for source in sources:
-                current_name_to_id[source["name"]] = source["id"]
+                current_name_to_id[source["name"]] = source["id"]["id"]
 
             import_id_to_name = {}
             for source_to_import in data:
@@ -589,7 +543,6 @@ class ApiManager:
         for source in sources:
             source_id_to_data[source["id"]["id"]] = source
 
-
         pipeline_info = self.pipelines.get_pipeline(org_id=org_id, pipeline_id=pipeline_id)
 
         for component in pipeline_info["pipeline"]["data"]["components"]:
@@ -1069,6 +1022,7 @@ class ApiManager:
                     )
 
                 else:
+
                     err = self.use_existing_datasets(
                         org_id=org_id,
                         pipeline_id=created_pipeline_id,
