@@ -42,6 +42,7 @@ class ApiRequestManager:
         self.content_octet = {"content-type": "application/octet-stream"}
         self.upload_content_type_header = {"Content-Type": "multipart/form-data"}
         self.delete_content_type_header = {"Content-Type": "application/json"}
+        self.different_content_type={"'Content-Type'": "application/json"}
 
         self.list_templates_uri = 'api/assetTemplates'
 
@@ -183,3 +184,16 @@ class ApiRequestManager:
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         pass
+
+    def simple_get(self, final_url):
+
+        header = self.build_header(
+            others=self.content_type_header
+        )
+
+        query_results = self.session.get(
+            final_url,
+            headers=header
+        )
+
+        return query_results
