@@ -57,6 +57,10 @@ class OrgAdmin(ApiRequestManager):
             self.org_info_url = remote + 'api/v1/orgs/{}'
             self.who_ami_url = remote + 'api/whoami'
             self.org_sensor_analytics = remote + "api/v1/orgs/{}/sensor_diagnostics"
+            self.change_group_url = remote + "api/authz/v1/groups/{}/users"
+            self.all_users_url = remote + "api/v1/users"
+            self.all_users_on_org = remote + "api/v1/orgs/{}/users"
+            self.all_groups_url = remote + "api/authz/v1/groups"
 
         except Exception as error:
             raise error
@@ -308,3 +312,83 @@ class OrgAdmin(ApiRequestManager):
 
         except Exception as error:
             raise error
+
+    def move_user_to_group(self, user_id, group_id):
+        """
+        Change user to a given group
+        :param user_id:
+        :param group_id:
+        :return:
+        """
+
+        try:
+
+            header = self.build_header(
+                others=self.different_content_type
+            )
+
+            invite_user_post = self.session.post(
+                self.change_group_url.format(group_id),
+                headers=header,
+                data=str(user_id)
+            )
+
+            if invite_user_post.status_code in range(200, 201):
+                return json.loads(invite_user_post.content)
+
+            raise Exception(json.loads(invite_user_post.content))
+
+        except Exception as error:
+
+            raise error
+
+    def retrieve_all_users(self):
+        """
+        Retrieves all users who the loged in user can retrieve
+        :return:
+        """
+        try:
+            all_users_list = self.simple_get(final_url=self.all_users_url)
+
+            if all_users_list.status_code in range(200, 201):
+                return json.loads(all_users_list.content)
+
+            raise Exception(json.loads(all_users_list.content))
+
+        except Exception as error:
+
+            raise error
+
+    def retrieve_all_users_form_org(self, org_id):
+        """
+        Retrieves all users who the loged in user can retrieve
+        :return:
+        """
+        try:
+            all_users_list = self.simple_get(final_url=self.all_users_on_org.format(org_id))
+
+            if all_users_list.status_code in range(200, 201):
+                return json.loads(all_users_list.content)
+
+            raise Exception(json.loads(all_users_list.content))
+
+        except Exception as error:
+
+            raise error
+
+    def get_all_groups(self):
+        """
+
+        :return:
+        """
+        try:
+            all_users_list = self.simple_get(final_url=self.all_groups_url)
+
+            if all_users_list.status_code in range(200, 201):
+                return json.loads(all_users_list.content)
+
+            raise Exception(json.loads(all_users_list.content))
+
+        except Exception as error:
+
+            raise error
