@@ -1026,16 +1026,22 @@ class Sources(ApiRequestManager):
         raise Exception(repr(post_upload_file.content))
 
     @single_org
-    def get_sources(self, org_id=None):
+    def get_sources(self, org_id=None, page_num=1, page_size=200):
+
         """
         Retrieves all the metadata of datasets on an org.
 
         :param org_id: Org to be queried
         :type org_id: int or str
+        :param page_num: pagination page number
+        :param page_size: pagination page size
         :return:
         """
 
-        query = self.gql_builder.build_dataset_query()
+        query = self.gql_builder.build_dataset_query(
+            page_num=page_num,
+            page_size=page_size
+        )
 
         get_sources_request = self.graph_ql_query(org_id=org_id, query=query)
 
